cwvreg.py
changeset 9258 4e79f587c6ab
parent 9256 697a8181ba30
child 9367 c8a5f7f43c03
--- a/cwvreg.py	Mon Aug 26 16:15:29 2013 +0200
+++ b/cwvreg.py	Mon Aug 26 11:36:19 2013 +0200
@@ -653,13 +653,13 @@
     def initialization_completed(self):
         """cw specific code once vreg initialization is completed:
 
-        * remove objects requiring a missing interface, unless
-          config.cleanup_interface_sobjects is false
+        * remove objects requiring a missing appobject, unless
+          config.cleanup_unused_appobjects is false
         * init rtags
         """
         # we may want to keep interface dependent objects (e.g.for i18n
         # catalog generation)
-        if self.config.cleanup_interface_sobjects:
+        if self.config.cleanup_unused_appobjects:
             # remove appobjects which depend on other, unexistant appobjects
             for obj, (regname, regids) in self._needs_appobject.items():
                 try:
@@ -679,8 +679,8 @@
         if 'uicfg' in self: # 'uicfg' is not loaded in a pure repository mode
             for rtags in self['uicfg'].itervalues():
                 for rtag in rtags:
-                    # don't check rtags if we don't want to cleanup_interface_sobjects
-                    rtag.init(self.schema, check=self.config.cleanup_interface_sobjects)
+                    # don't check rtags if we don't want to cleanup_unused_appobjects
+                    rtag.init(self.schema, check=self.config.cleanup_unused_appobjects)
 
     # rql parsing utilities ####################################################